pub struct FittedOneHotEncoder { /* private fields */ }Expand description
Fitted OneHotEncoder — holds the number of unique categories per column.
Implementations
Sourceimpl FittedOneHotEncoder
impl FittedOneHotEncoder
Sourcepub fn transform(
&self,
x: &ArrayBase<OwnedRepr<usize>, Dim<[usize; 2]>>,
) -> Result<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>>, RustMlError>
pub fn transform( &self, x: &ArrayBase<OwnedRepr<usize>, Dim<[usize; 2]>>, ) -> Result<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>>, RustMlError>
Transform integer-encoded data into one-hot encoded data.
Each input column of k categories is expanded into k binary columns.
Sourcepub fn categories(&self) -> &[usize]
pub fn categories(&self) -> &[usize]
Return the number of categories per original column.
Sourcepub fn n_output_features(&self) -> usize
pub fn n_output_features(&self) -> usize
Return the total number of output columns after one-hot encoding.