pub struct StandardScaler {
pub with_mean: bool,
pub with_std: bool,
}Expand description
Parameters for StandardScaler (unfitted state).
Standardizes features by removing the mean and scaling to unit variance:
z = (x - mean) / std
Fields
with_mean: boolIf true, center data to zero mean before scaling.
with_std: boolIf true, scale data to unit variance.
Implementations
Sourceimpl StandardScaler
impl StandardScaler
Sourcepub fn new() -> StandardScaler
pub fn new() -> StandardScaler
Create a new StandardScaler with defaults (both centering and scaling enabled).
Sourcepub fn with_mean(self, with_mean: bool) -> StandardScaler
pub fn with_mean(self, with_mean: bool) -> StandardScaler
Set whether to center data to zero mean before scaling.
Sourcepub fn with_std(self, with_std: bool) -> StandardScaler
pub fn with_std(self, with_std: bool) -> StandardScaler
Set whether to scale data to unit variance.